@@ -1,22 +1,8 @@
-/***************************************************************************
- *                                                                         *
- *   Copyright 2014 Sebastian Kügler <sebas@kde.org>                       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2014 Sebastian Kügler <sebas@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 // Qt
 #include <QApplication>
@@ -144,6 +130,6 @@ int main(int argc, char **argv)
     qmlRegisterAnonymousType<CuttleFish::IconModel>("org.kde.plasma.sdk", 1);
     qmlRegisterAnonymousType<CuttleFish::ColorSchemes>("org.kde.plasma.sdk", 1);
 #endif
-
+    app.setAttribute(Qt::AA_UseHighDpiPixmaps);
     return app.exec();
 }
