@@ -1,22 +1,10 @@
 /*
-   Copyright (c) 2003 Scott Wheeler <wheeler@kde.org>
-   Copyright (c) 2005 Rafal Rzepecki <divide@users.sourceforge.net>
-   Copyright (c) 2006 Hamish Rodda <rodda@kde.org>
-   Copyright 2007 Pino Toscano <pino@kde.org>
+   SPDX-FileCopyrightText: 2003 Scott Wheeler <wheeler@kde.org>
+   SPDX-FileCopyrightText: 2005 Rafal Rzepecki <divide@users.sourceforge.net>
+   SPDX-FileCopyrightText: 2006 Hamish Rodda <rodda@kde.org>
+   SPDX-FileCopyrightText: 2007 Pino Toscano <pino@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "ktreeviewsearchline.h"
@@ -33,7 +21,6 @@
 #include <QTreeView>
 
 #include <QDebug>
-#include <kiconloader.h>
 #include <klocalizedstring.h>
 
 class KTreeViewSearchLinePrivate
